@@ -1,5 +1,10 @@
 """A module for connecting to a NuoDB database.
 
+(C) Copyright 2013-2020 NuoDB, Inc.  All Rights Reserved.
+
+This software is licensed under a BSD 3-Clause License.
+See the LICENSE file provided with this software.
+
 Exported Classes:
 Connection -- Class for establishing connection with host.
 
@@ -22,7 +27,7 @@ threadsafety = 1
 paramstyle = "qmark"
 
 
-def connect(database, host, user, password, options=None):
+def connect(database, host, user, password, options=None, **kwargs):
     """Creates a connection object.
     Arguments:
     database -- Name of the database to access.
@@ -39,7 +44,7 @@ def connect(database, host, user, password, options=None):
     :type password: str
     :type options: dict[str,str]
     """
-    return Connection(database, host, user, password, options)
+    return Connection(database, host, user, password, options, **kwargs)
 
 
 class Connection(object):
@@ -62,11 +67,11 @@ class Connection(object):
     auto_commit (setter) -- Sets the value of auto_commit on the database.
     """
 
-    from .exception import Warning, Error, InterfaceError, DatabaseError, \
-                OperationalError, IntegrityError, InternalError, \
-                ProgrammingError, NotSupportedError
+    from .exception import Warning, Error, InterfaceError, DatabaseError
+    from .exception import OperationalError, IntegrityError, InternalError
+    from .exception import ProgrammingError, NotSupportedError
 
-    def __init__(self, dbName, broker, username, password, options):
+    def __init__(self, dbName, broker, username, password, options, **kwargs):
         """Constructor for the Connection class.
 
         Arguments:
@@ -77,6 +82,7 @@ class Connection(object):
         options -- A dictionary of NuoDB connection options
             Some common options include:
             "schema"
+        kwargs -- Extra arguments passed to EncodedSession
 
         Returns:
         a Connection instance
@@ -89,7 +95,7 @@ class Connection(object):
         """
         (host, port) = getCloudEntry(broker, dbName, options=options)
 
-        self.__session = EncodedSession(host, port, options=options)
+        self.__session = EncodedSession(host, port, options=options, **kwargs)
 
         self._trans_id = None
 
