@@ -1,4 +1,10 @@
-__author__ = 'jgetto'
+"""NuoDB Python driver SQL statement
+
+(C) Copyright 2013-2020 NuoDB, Inc.  All Rights Reserved.
+
+This software is licensed under a BSD 3-Clause License.
+See the LICENSE file provided with this software.
+"""
 
 
 class Statement(object):
